#!/usr/bin/env python
#
# Script: dump_TiePoint2xyz.py
# Purpose : dump data from an existing ContextCapture project
# Keywords: project reading, project data acess
#
# Script description: This script loads a project and dumps project contents.
# ******************************************************************************

import sys
import ccmasterkernel
import os

# Note: replace paths with your references, or install SDK sample data in C:/CC_SDK_DATA
projectDirPath = 'E:/ContextCapture-center/test'
outputFilePath = 'E:/ContextCapture-center/test/ATPoints.txt'

projectName = os.path.basename(projectDirPath)+'.ccm'
projectFilePath = os.path.join(projectDirPath, projectName)

def main():
	print('MasterKernel version %s' % ccmasterkernel.version())
	print('')
	
	# --------------------------------------------------------------------
	# load project
	# --------------------------------------------------------------------
	project = ccmasterkernel.Project()
	err = project.readFromFile(projectFilePath)
	if not err.isNone():
		print('Failed to load project. ' + projectFilePath + ' ' + err.message)
		sys.exit(0)

	print('Project %s successfully loaded.' % project.getName())
	print('')
	

	# --------------------------------------------------------------------
	# display project tree
	# --------------------------------------------------------------------
	for iBlock in range(0, project.getNumBlocks()):
		block = project.getBlock(iBlock)
		print(str(iBlock) + ' -[%s]' % block.getName())
		for iReconstruction in range(0, block.getNumReconstructions()):
			reconstruction = block.getReconstruction(iReconstruction)
			print('	 -[%s]' % reconstruction.getName())
			for iProduction in range(0, reconstruction.getNumProductions()):
				production = reconstruction.getProduction(iProduction)
				print('		 -[%s]' % production.getName())


	print('')
	
	iBlock = input('Enter a number:')
	#print (iBlock)
	if iBlock == '': 
		sys.exit(0)
	print('')
	
	# --------------------------------------------------------------------
	# display block details
	# --------------------------------------------------------------------

	block = project.getBlock(int(iBlock))

	print('--------------------------------------')
	print('Loading: '+'[%s]:' % block.getName())

	# AT
	AT = block.getAT()
	if AT == None:
		print('No Aerotriangulation results')
		sys.exit(0)


	# photogroups/photos
	SparsePoints = block.getNumTiePoints()
	print('NumTiePoints: ' + str(SparsePoints))
	if block.getNumTiePoints() == 0:
		print("Error: Missing tie points.")
		sys.exit(0)
		
	f = open(outputFilePath, 'w')
	#f.write("x,y,z,R,G,B\n")
	numPositionsWritten = 0	
	#point=block.getTiePoint(1)
	#print(type(point))
	#help(ccmasterkernel.bindings.TiePoint)
	#print(point.position.x)
	#print(point.color[1])
	
	for p in range(0, SparsePoints):
		ATpointpos = block.getTiePoint(p).position
		ATpointRGB = block.getTiePoint(p).color
		f.write("%s,%s,%s,%.0f,%.0f,%.0f" % (ATpointpos.x, ATpointpos.y, ATpointpos.z,ATpointRGB[0], ATpointRGB[1], ATpointRGB[2]))
		
		f.write("\n")
		numPositionsWritten = numPositionsWritten + 1
	f.close()
	
	print('File successfully created: %s' % outputFilePath)
	print('%s points written' % numPositionsWritten)
	
if __name__ == '__main__':
	main()
